==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/admin/messages/fi/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => '<strong>Ajastettujen tehtävien</strong> Tila',
    '<strong>Queue</strong> Status' => '<strong>Jono</strong> Tila',
    'About HumHub' => 'Tietoja',
    'Background Jobs' => 'Taustatiedot',
    'Base URL' => 'Perus URL',
    'Checking HumHub software prerequisites.' => 'Järjestelmän vaatimukset.',
    'Database' => 'Tietokanta',
    'Database migration results:' => 'Tietokannan muuttoksentulokset:',
    'Delayed' => 'Myöhästyneet',
    'Displaying {count} entries per page.' => 'Näytetään {count} tulosta sivua kohden',
    'Done' => 'Valmis',
    'Driver' => 'Ohelmisto',
    'Error' => 'Virhe',
    'Flush entries' => 'Poista kohteet',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'Järjestelmä on tällä hetkellä debug-tilassa. Poista se ennen käyttöä!',
    'Info' => 'Info',
    'Last run (daily):' => 'Viimeisin tehty tehtävä (Päivä):',
    'Last run (hourly):' => 'Viimeisin tehty tehtävä (Tunti):',
    'Licences' => 'Lisenssit',
    'Logging' => 'Valvonta',
    'Never' => 'Ei koskaan',
    'Other' => 'Muu',
    'Permissions' => 'Käyttöoikeudet',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Tutustu dokumentaatioon cronjobs- ja jonotyöntekijöiden asettamiseksi.',
    'Prerequisites' => 'Edellytykset',
    'Queue successfully cleared.' => 'Jono tyhjennetiin onnistuneesti',
    'Re-Run tests' => 'Testaa',
    'Reserved' => 'Varattu',
    'Search index rebuild in progress.' => 'Hakemiston järjestely käynnissä.',
    'Search term...' => 'Hakusana...',
    'See installation manual for more details.' => 'Kysy lisätietoja järjestelmän valvojalta.',
    'Select category..' => 'Valitse kategoria..',
    'Select day' => 'Valitse päivä',
    'Select level...' => 'Valitse taso...',
    'Settings' => 'Asetukset',
    'The current main HumHub database name is ' => 'Järjestelmän tämän hetkisen tietokannan nimi',
    'There is a new update available! (Latest version: %version%)' => 'Uusi päivitys saatavilla! (Viimeisin versio: %version%)',
    'This HumHub installation is up to date!' => 'Järjestelmä on ajan tasalla!',
    'Total {count} entries found.' => 'Yhteensä {count} tulosta löytyi.',
    'Trace' => 'Jäljitä',
    'Waiting' => 'Odottaa',
    'Warning' => 'Varoitus',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    'Assets' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Dynamic Config' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Outstanding database migrations:' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Runtime' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/fi/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => '<strong>Ajastettujen tehtävien</strong> Tila',
    '<strong>Queue</strong> Status' => '<strong>Jono</strong> Tila',
    'About HumHub' => 'Tietoja',
    'Background Jobs' => 'Taustatiedot',
    'Base URL' => 'Perus URL',
    'Checking HumHub software prerequisites.' => 'Järjestelmän vaatimukset.',
    'Database' => 'Tietokanta',
    'Database migration results:' => 'Tietokannan muuttoksentulokset:',
    'Delayed' => 'Myöhästyneet',
    'Displaying {count} entries per page.' => 'Näytetään {count} tulosta sivua kohden',
    'Done' => 'Valmis',
    'Driver' => 'Ohelmisto',
    'Error' => 'Virhe',
    'Flush entries' => 'Poista kohteet',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'Järjestelmä on tällä hetkellä debug-tilassa. Poista se ennen käyttöä!',
    'Info' => 'Info',
    'Last run (daily):' => 'Viimeisin tehty tehtävä (Päivä):',
    'Last run (hourly):' => 'Viimeisin tehty tehtävä (Tunti):',
    'Licences' => 'Lisenssit',
    'Logging' => 'Valvonta',
    'Never' => 'Ei koskaan',
    'Other' => 'Muu',
    'Permissions' => 'Käyttöoikeudet',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Tutustu dokumentaatioon cronjobs- ja jonotyöntekijöiden asettamiseksi.',
    'Prerequisites' => 'Edellytykset',
    'Queue successfully cleared.' => 'Jono tyhjennetiin onnistuneesti',
    'Re-Run tests' => 'Testaa',
    'Reserved' => 'Varattu',
    'Search index rebuild in progress.' => 'Hakemiston järjestely käynnissä.',
    'Search term...' => 'Hakusana...',
    'See installation manual for more details.' => 'Kysy lisätietoja järjestelmän valvojalta.',
    'Select category..' => 'Valitse kategoria..',
    'Select day' => 'Valitse päivä',
    'Select level...' => 'Valitse taso...',
    'Settings' => 'Asetukset',
    'The current main HumHub database name is ' => 'Järjestelmän tämän hetkisen tietokannan nimi',
    'There is a new update available! (Latest version: %version%)' => 'Uusi päivitys saatavilla! (Viimeisin versio: %version%)',
    'This HumHub installation is up to date!' => 'Järjestelmä on ajan tasalla!',
    'Total {count} entries found.' => 'Yhteensä {count} tulosta löytyi.',
    'Trace' => 'Jäljitä',
    'Waiting' => 'Odottaa',
    'Warning' => 'Varoitus',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    'Assets' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Enable <a href="{url}">Link Redirection Service</a>' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for Mercure push live driver' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Outstanding database migrations:' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Runtime' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Uploads - File' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];
